# Official YOLOv0

Implementation of paper - [YOLOv0](https://www.youtube.com/watch?v=dQw4w9WgXcQ)

We achieved `skynet` on COCO dataset

<img width=500px src="docs/moon.png"/>

## Installation

```
pip install cvevals
```